/*
 * BusinessObjectTest.java
 * JUnit based test
 *
 * Created on 18. leden 2007, 9:31
 */

package cz.novoj.emt;

import cz.novoj.emt.exceptions.SendException;
import org.junit.*;
import static org.junit.Assert.*;
import static org.easymock.EasyMock.*;

/**
 * Test for business object.
 * 
 * @author Rodina Novotnych
 */
public class BusinessObjectMockTest {
    private BusinessObject tested;
    
    /**
     * Tests performBusinessLogic with test Mocks.
     **/
    @Test 
    public void testPerformBusinessLogicWithMocksLowerBound() throws SendException {
        tested = new BusinessObject();
        ILogger loggerMock = createMock(ILogger.class); //1
        IMessageSender messageMock = createMock(IMessageSender.class); //1
        messageMock.send(
                    BusinessObject.RECEIVER_ONE, 
                    BusinessObject.SENDER, 
                    BusinessObject.SUBJECT, 
                    BusinessObject.BODY_LOWER_BOUND); //2
        
        replay(loggerMock, messageMock); //3
        
        tested.setLogger(loggerMock);  //4
        tested.setMessageSender(messageMock); //4
        tested.performBussinesLogic(1); //5
        
        verify(loggerMock, messageMock); //6
    }
    
    /**
     * Tests performBusinessLogic with test Mocks.
     **/
    @Test 
    public void testPerformBusinessLogicWithMocksHigherBound() throws SendException {
        tested = new BusinessObject();
        ILogger loggerMock = createMock(ILogger.class); //1
        IMessageSender messageMock = createMock(IMessageSender.class); //1
        messageMock.send(
                    BusinessObject.RECEIVER_TWO, 
                    BusinessObject.SENDER, 
                    BusinessObject.SUBJECT, 
                    BusinessObject.BODY_HIGHER_BOUND); //2
        
        replay(loggerMock, messageMock); //3
        
        tested.setLogger(loggerMock); //4
        tested.setMessageSender(messageMock); //4
        tested.performBussinesLogic(11); //5
        
        verify(loggerMock, messageMock); //6
    }
    
    /**
     * Tests performBusinessLogic with test Mocks.
     **/
    @Test 
    public void testPerformBusinessLogicWithMocksWithException() throws SendException {
        tested = new BusinessObject(); //1
        ILogger loggerMock = createMock(ILogger.class); //2
        loggerMock.logError((String) notNull(), isA(SendException.class)); //3
        
        IMessageSender messageMock = createMock(IMessageSender.class); //2
        messageMock.send(
                    BusinessObject.RECEIVER_ONE, 
                    BusinessObject.SENDER, 
                    BusinessObject.SUBJECT, 
                    BusinessObject.BODY_LOWER_BOUND); //4
        expectLastCall().andThrow(new SendException()); //5
        
        replay(loggerMock, messageMock); //6
        
        tested.setLogger(loggerMock); //7
        tested.setMessageSender(messageMock); //7
        tested.performBussinesLogic(1); //8
        
        verify(loggerMock, messageMock); //9
    }    
    
}
