/*
 * BusinessObjectTest.java
 * JUnit based test
 *
 * Created on 18. leden 2007, 9:31
 */

package cz.novoj.emt;

import cz.novoj.emt.exceptions.SendException;
import org.junit.*;
import static org.junit.Assert.*;

/**
 * Test for business object with Stubs.
 * 
 * @author Rodina Novotnych
 */
public class BusinessObjectStubTest {
    private BusinessObject tested;
    
    /**
     * Tests performBusinessLogic with test stubs.
     **/
    @Test 
    public void testPerformBusinessLogicWithStubsLowerBound() {
        tested = new BusinessObject();
        StubLogger loggerStub = new StubLogger(null);
        StubMessageSender messageStub = new StubMessageSender(
                    BusinessObject.RECEIVER_ONE, 
                    BusinessObject.SENDER, 
                    BusinessObject.SUBJECT, 
                    BusinessObject.BODY_LOWER_BOUND);
        
        tested.setLogger(loggerStub);
        tested.setMessageSender(messageStub);
        tested.performBussinesLogic(1);
        
        loggerStub.verifyCalls(0);
        messageStub.verifyCalls(1);
    }
    
    /**
     * Tests performBusinessLogic with test stubs.
     **/
    @Test 
    public void testPerformBusinessLogicWithStubsHigherBound() {
        tested = new BusinessObject();
        StubLogger loggerStub = new StubLogger(null);
        StubMessageSender messageStub = new StubMessageSender(
                    BusinessObject.RECEIVER_TWO, 
                    BusinessObject.SENDER, 
                    BusinessObject.SUBJECT, 
                    BusinessObject.BODY_HIGHER_BOUND);
        
        tested.setLogger(loggerStub);
        tested.setMessageSender(messageStub);
        tested.performBussinesLogic(11);
        
        loggerStub.verifyCalls(0);
        messageStub.verifyCalls(1);
    }
    
    /**
     * Tests performBusinessLogic with test stubs.
     **/
    @Test 
    public void testPerformBusinessLogicWithStubsWithException() {
        tested = new BusinessObject();
        StubLogger loggerStub = new StubLogger(new SendException());
        StubExceptionMessageSender messageStub = new StubExceptionMessageSender();
        
        tested.setLogger(loggerStub);
        tested.setMessageSender(messageStub);
        tested.performBussinesLogic(1);
        
        loggerStub.verifyCalls(1);
    }
    
}
